==> kdevplatform-0.9.93.tar.bz2: kdevplatform-0.9.93/vcs/vcsjob.cpp <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "vcsjob.h"

//#include <klocale.h>

namespace KDevelop
{
    class VcsJobPrivate
    {
        public:
            VcsJob::JobType m_type;
    };

    VcsJob::VcsJob( QObject* parent )
        : OutputJob(parent), d(new VcsJobPrivate)
    {
        setStandardToolView(IOutputView::VcsView);
    }

    VcsJob::~VcsJob()
    {
        delete d;
    }

    VcsJob::JobType VcsJob::type()
    {
        return d->m_type;
    }

    void VcsJob::setType( VcsJob::JobType t )
    {
        d->m_type = t;
    }
}

#include "vcsjob.moc"

==> kdevplatform-0.9.95.tar.bz2: kdevplatform-0.9.95/vcs/vcsjob.cpp <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "vcsjob.h"

//#include <klocale.h>

namespace KDevelop
{
    class VcsJobPrivate
    {
        public:
            VcsJob::JobType m_type;
    };

    VcsJob::VcsJob( QObject* parent, OutputJobVerbosity verbosity )
        : OutputJob(parent, verbosity), d(new VcsJobPrivate)
    {
        setStandardToolView(IOutputView::VcsView);
        startOutput();
    }

    VcsJob::~VcsJob()
    {
        delete d;
    }

    VcsJob::JobType VcsJob::type()
    {
        return d->m_type;
    }

    void VcsJob::setType( VcsJob::JobType t )
    {
        d->m_type = t;
    }
}

#include "vcsjob.moc"
